.. image:: https://secure.travis-ci.org/collective/collective.celery.png?branch=master
    :target: http://travis-ci.org/collective/collective.celery
    :alt: Travis CI badge

.. image:: https://pypip.in/d/collective.celery/badge.png
    :target: https://pypi.python.org/pypi/collective.celery/
    :alt: Downloads


``collective.celery`` provides the necessary bits to use `Celery <http://celery.readthedocs.org/en/latest/>`_ within `Plone <http://plone.org/>`_.

Much of the code here is based off of David Glick's gists, Asko's work and `pyramid_celery <https://pypi.python.org/pypi/pyramid_celery/>`_.

